@@ -2,6 +2,8 @@ mod build_info_abi;
 mod contract_abi;
 mod endpoint_abi;
 mod type_abi;
+mod type_abi_impl_basic;
+mod type_abi_impl_codec_multi;
 mod type_description;
 mod type_description_container;
 
@@ -12,4 +14,7 @@ pub use type_abi::*;
 pub use type_description::*;
 pub use type_description_container::*;
 
+/// Used in generating the ABI.
+pub use git_version::git_version;
+
 pub type TypeName = crate::String;
