@@ -1,8 +1,13 @@
-use crate::types::{BoxedBytes, MessageHashType, H256};
-use alloc::boxed::Box;
+use crate::types::{BoxedBytes, MessageHashType};
 
 use super::{Handle, ManagedTypeApi, ManagedTypeApiImpl};
 
+pub const SHA256_RESULT_LEN: usize = 32;
+pub const KECCAK256_RESULT_LEN: usize = 32;
+pub const RIPEMD_RESULT_LEN: usize = 20;
+pub const ED25519_KEY_BYTE_LEN: usize = 32;
+pub const ED25519_SIGNATURE_BYTE_LEN: usize = 64;
+
 pub trait CryptoApi: ManagedTypeApi {
     type CryptoApiImpl: CryptoApiImpl;
 
@@ -10,29 +15,15 @@ pub trait CryptoApi: ManagedTypeApi {
 }
 
 pub trait CryptoApiImpl: ManagedTypeApiImpl {
-    fn sha256_legacy(&self, data: &[u8]) -> H256;
+    fn sha256_legacy(&self, data: &[u8]) -> [u8; SHA256_RESULT_LEN];
 
-    fn sha256(&self, data_handle: Handle) -> Handle {
-        // default implementation used in debugger
-        // the VM has a dedicated hook
-        self.mb_new_from_bytes(
-            self.sha256_legacy(self.mb_to_boxed_bytes(data_handle).as_slice())
-                .as_array(),
-        )
-    }
+    fn sha256(&self, data_handle: Handle) -> Handle;
 
-    fn keccak256_legacy(&self, data: &[u8]) -> H256;
+    fn keccak256_legacy(&self, data: &[u8]) -> [u8; KECCAK256_RESULT_LEN];
 
-    fn keccak256(&self, data_handle: Handle) -> Handle {
-        // default implementation used in debugger
-        // the VM has a dedicated hook
-        self.mb_new_from_bytes(
-            self.keccak256_legacy(self.mb_to_boxed_bytes(data_handle).as_slice())
-                .as_array(),
-        )
-    }
+    fn keccak256(&self, data_handle: Handle) -> Handle;
 
-    fn ripemd160(&self, data: &[u8]) -> Box<[u8; 20]>;
+    fn ripemd160(&self, data: &[u8]) -> [u8; RIPEMD_RESULT_LEN];
 
     fn verify_bls(&self, key: &[u8], message: &[u8], signature: &[u8]) -> bool;
 
