@@ -1,9 +1,17 @@
-use crate::api::{EndpointArgumentApi, Handle};
+use crate::api::{endpoint_arg_api::EndpointArgumentApiImpl, EndpointArgumentApi, Handle};
 use alloc::vec::Vec;
 
 use super::UncallableApi;
 
 impl EndpointArgumentApi for UncallableApi {
+    type EndpointArgumentApiImpl = UncallableApi;
+
+    fn argument_api_impl() -> Self::EndpointArgumentApiImpl {
+        unreachable!()
+    }
+}
+
+impl EndpointArgumentApiImpl for UncallableApi {
     fn get_num_arguments(&self) -> i32 {
         unreachable!()
     }
