@@ -50,21 +50,36 @@ where
     /// but the EGLD TokenIdentifier is serialized as `EGLD`.
     /// Warning, not tested with multi transfer, use `all_esdt_transfers` instead!
     pub fn token(&self) -> TokenIdentifier<A> {
-        TokenIdentifier::from_raw_handle(A::call_value_api_impl().token())
+        let call_value_api = A::call_value_api_impl();
+        if call_value_api.esdt_num_transfers() == 0 {
+            TokenIdentifier::egld()
+        } else {
+            TokenIdentifier::from_raw_handle(call_value_api.token())
+        }
     }
 
     /// Returns the nonce of the received ESDT token.
     /// Will return 0 in case of EGLD or fungible ESDT transfer.
     /// Warning, not tested with multi transfer, use `all_esdt_transfers` instead!
     pub fn esdt_token_nonce(&self) -> u64 {
-        A::call_value_api_impl().esdt_token_nonce()
+        let call_value_api = A::call_value_api_impl();
+        if call_value_api.esdt_num_transfers() > 0 {
+            call_value_api.esdt_token_nonce()
+        } else {
+            0
+        }
     }
 
     /// Returns the ESDT token type.
     /// Will return "Fungible" for EGLD.
     /// Warning, not tested with multi transfer, use `all_esdt_transfers` instead!
     pub fn esdt_token_type(&self) -> EsdtTokenType {
-        A::call_value_api_impl().esdt_token_type()
+        let call_value_api = A::call_value_api_impl();
+        if call_value_api.esdt_num_transfers() > 0 {
+            A::call_value_api_impl().esdt_token_type()
+        } else {
+            EsdtTokenType::Fungible
+        }
     }
 
     pub fn require_egld(&self) -> BigUint<A> {
@@ -87,4 +102,20 @@ where
             TokenIdentifier::from_raw_handle(token_handle),
         )
     }
+
+    pub fn payment(&self) -> EsdtTokenPayment<A> {
+        let api = A::call_value_api_impl();
+        if api.esdt_num_transfers() == 0 {
+            EsdtTokenPayment::new(TokenIdentifier::egld(), 0, self.egld_value())
+        } else {
+            EsdtTokenPayment::new(self.token(), self.esdt_token_nonce(), self.esdt_value())
+        }
+    }
+
+    pub fn payment_as_tuple(&self) -> (TokenIdentifier<A>, u64, BigUint<A>) {
+        let (amount, token) = self.payment_token_pair();
+        let nonce = self.esdt_token_nonce();
+
+        (token, nonce, amount)
+    }
 }
