@@ -4,7 +4,7 @@ use elrond_codec::{DecodeError, EncodeError};
 
 use crate::{
     api::{ErrorApiImpl, ManagedTypeApi},
-    types::{ManagedBuffer, ManagedSCError, ManagedType},
+    types::{BoxedBytes, ManagedBuffer, ManagedSCError, ManagedType},
 };
 
 #[derive(Default)]
@@ -50,6 +50,13 @@ impl<M: ManagedTypeApi> IntoSignalError<M> for &[u8] {
     }
 }
 
+impl<M: ManagedTypeApi> IntoSignalError<M> for BoxedBytes {
+    #[inline]
+    fn signal_error_with_message(self) -> ! {
+        M::error_api_impl().signal_error(self.as_slice())
+    }
+}
+
 impl<M: ManagedTypeApi> IntoSignalError<M> for EncodeError {
     #[inline]
     fn signal_error_with_message(self) -> ! {
