@@ -3,16 +3,15 @@ use core::marker::PhantomData;
 use super::{StorageClearable, StorageMapper};
 use crate::{
     abi::{TypeAbi, TypeDescriptionContainer, TypeName},
-    api::{EndpointFinishApi, ManagedTypeApi, StorageMapperApi},
-    finish_all,
-    io::EndpointResult,
+    api::StorageMapperApi,
     storage::{storage_get, storage_set, StorageKey},
     types::{ManagedType, MultiResultVec},
 };
 use alloc::vec::Vec;
 use elrond_codec::{
     elrond_codec_derive::{TopDecode, TopDecodeOrDefault, TopEncode, TopEncodeOrDefault},
-    DecodeDefault, EncodeDefault, TopDecode, TopEncode,
+    multi_encode_iter_or_handle_err, DecodeDefault, EncodeDefault, EncodeErrorHandler, TopDecode,
+    TopEncode, TopEncodeMulti, TopEncodeMultiOutput,
 };
 
 const NULL_ENTRY: u32 = 0;
@@ -450,18 +449,19 @@ where
 }
 
 /// Behaves like a MultiResultVec when an endpoint result.
-impl<SA, T> EndpointResult for QueueMapper<SA, T>
+impl<SA, T> TopEncodeMulti for QueueMapper<SA, T>
 where
     SA: StorageMapperApi,
-    T: TopEncode + TopDecode + EndpointResult,
+    T: TopEncode + TopDecode,
 {
-    type DecodeAs = MultiResultVec<T::DecodeAs>;
+    type DecodeAs = MultiResultVec<T>;
 
-    fn finish<FA>(&self)
+    fn multi_encode_or_handle_err<O, H>(&self, output: &mut O, h: H) -> Result<(), H::HandledErr>
     where
-        FA: ManagedTypeApi + EndpointFinishApi,
+        O: TopEncodeMultiOutput,
+        H: EncodeErrorHandler,
     {
-        finish_all::<FA, _, _>(self.iter());
+        multi_encode_iter_or_handle_err(self.iter(), output, h)
     }
 }
 
@@ -479,7 +479,7 @@ where
         T::provide_type_descriptions(accumulator);
     }
 
-    fn is_multi_arg_or_result() -> bool {
+    fn is_variadic() -> bool {
         true
     }
 }
