@@ -1,4 +1,5 @@
 use alloc::{string::String, vec::Vec};
+use elrond_codec::{EncodeErrorHandler, TopEncodeMulti, TopEncodeMultiOutput, TryStaticCast};
 
 use crate::{
     api::{EndpointFinishApi, ErrorApi, ErrorApiImpl, ManagedTypeApi},
@@ -25,6 +26,8 @@ where
     }
 }
 
+impl<M> TryStaticCast for ManagedSCError<M> where M: ManagedTypeApi + ErrorApi {}
+
 impl<M> ManagedSCError<M>
 where
     M: ManagedTypeApi + ErrorApi,
@@ -113,3 +116,18 @@ where
         ManagedSCError { buffer: message }
     }
 }
+
+impl<M> TopEncodeMulti for ManagedSCError<M>
+where
+    M: ManagedTypeApi + ErrorApi,
+{
+    type DecodeAs = Self;
+
+    fn multi_encode_or_handle_err<O, H>(&self, output: &mut O, h: H) -> Result<(), H::HandledErr>
+    where
+        O: TopEncodeMultiOutput,
+        H: EncodeErrorHandler,
+    {
+        output.push_multi_specialized(self, h)
+    }
+}
