@@ -1,4 +1,4 @@
-use elrond_codec::{DecodeError, EncodeError};
+use elrond_codec::{DecodeError, EncodeError, TopEncodeMulti, TryStaticCast};
 
 use crate::api::{EndpointFinishApi, ErrorApiImpl};
 
@@ -17,6 +17,8 @@ impl SCError for StaticSCError {
     }
 }
 
+impl TryStaticCast for StaticSCError {}
+
 impl StaticSCError {
     #[inline]
     pub fn as_bytes(&self) -> &[u8] {
@@ -57,3 +59,15 @@ impl From<!> for StaticSCError {
         unreachable!()
     }
 }
+
+impl TopEncodeMulti for StaticSCError {
+    type DecodeAs = Self;
+
+    fn multi_encode_or_handle_err<O, H>(&self, output: &mut O, h: H) -> Result<(), H::HandledErr>
+    where
+        O: elrond_codec::TopEncodeMultiOutput,
+        H: elrond_codec::EncodeErrorHandler,
+    {
+        output.push_multi_specialized(self, h)
+    }
+}
