@@ -1,16 +1,16 @@
 mod crypto;
-mod general;
+mod flags;
+mod heap;
 mod interaction;
 mod io;
 mod managed;
-mod managed_codec;
 mod static_buffer;
 
 pub use super::{Box, Vec};
 pub use crypto::*;
-pub use general::*;
+pub use flags::*;
+pub use heap::*;
 pub use interaction::*;
 pub use io::*;
 pub use managed::*;
-pub use managed_codec::*;
 pub use static_buffer::*;
